/*============================================================================
  File:     EmployeeCaseStudy-TableDefinition.sql

  Summary:  Review the table creation of the Employee Table
			table shown in Index Internals.
  
  Date:     October 2008
------------------------------------------------------------------------------
  Written by Kimberly L. Tripp, SYSolutions, Inc.

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  This script is intended only as a supplement to demos and lectures
  given by Kimberly L. Tripp.  
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- These samples use the SQL Server 2008 "IndexInternals" database. 
-- Restore from class samples.
-- NOTE: This is a compressed SQL Server 2008 backup.

USE IndexInternals
go

CREATE TABLE Employee
(
EmployeeID      Int				NOT NULL	Identity,
LastName        nchar(30)		NOT NULL, -- created as fixed width to make my row size 400 bytes (to simplify the math)
FirstName       nchar(29)		NOT NULL,
MiddleInitial	nchar(1)		NULL,
SSN				char(11)		NOT NULL,
OtherColums		char(258)		NOT NULL	DEFAULT 'Junk'
) 
go

-- Add the clustered index
ALTER TABLE Employee
	ADD CONSTRAINT EmployeePK
		PRIMARY KEY CLUSTERED (EmployeeID)
ON [PRIMARY]
go

-- Add the nonclustered unique key
ALTER TABLE Employee
	ADD CONSTRAINT EmployeeSSNUK
		UNIQUE NONCLUSTERED (SSN)
go

sp_help Employee
go
sp_helpindex2 Employee
go

-- Create the Heap Version

CREATE TABLE EmployeeHeap
(
EmployeeID      Int				NOT NULL	Identity,
LastName        nchar(30)		NOT NULL, -- created as fixed width to make my row size 400 bytes (to simplify the math)
FirstName       nchar(29)		NOT NULL,
MiddleInitial	nchar(1)		NULL,
SSN				char(11)		NOT NULL,
OtherColums		char(258)		NOT NULL	DEFAULT 'Junk'
) 
go

INSERT EmployeeHeap (LastName, Firstname, MiddleInitial, SSN)
    SELECT LastName, Firstname, MiddleInitial, SSN
    FROM Employee

-- Add a nonclustered index for EmployeeID
ALTER TABLE EmployeeHeap
	ADD CONSTRAINT EmployeeHeapPK
		PRIMARY KEY NONCLUSTERED (EmployeeID)
ON [PRIMARY]
go

-- Add the nonclustered unique key
ALTER TABLE EmployeeHeap
	ADD CONSTRAINT SSNHeapUK
		UNIQUE NONCLUSTERED (SSN)
go

sp_help EmployeeHeap
go
sp_helpindex2 Employee
go
